@@ -1,5 +1,6 @@
 from viadot.tasks import C4CToDF, C4CReportToDF
 from viadot.config import local_config
+from prefect.tasks.secrets import PrefectSecret
 
 
 def test_c4c_to_df():
@@ -8,7 +9,6 @@ def test_c4c_to_df():
     c4c_to_df = C4CToDF()
     df = c4c_to_df.run(url=url, endpoint=endpoint)
     answer = df.head()
-
     assert answer.shape[1] == 23
 
 
@@ -21,3 +21,11 @@ def test_c4c_report_to_df():
     answer = df.head()
 
     assert answer.shape[0] == 5
+
+
+def test_c4c_to_df_kv():
+    task = C4CToDF()
+    credentials_secret = PrefectSecret("C4C_KV").run()
+    res = task.run(credentials_secret=credentials_secret, endpoint="ActivityCollection")
+    answer = res.head()
+    assert answer.shape[1] == 19
