@@ -1,6 +1,6 @@
 import os
 from typing import Any, Dict, List, Union
-
+from pathlib import Path
 import pendulum
 from prefect import Flow, Task, apply_map
 from prefect.backend import set_key_value
@@ -59,6 +59,7 @@ class SupermetricsToADLS(Flow):
         keep_validation_output: bool = False,
         output_file_extension: str = ".parquet",
         local_file_path: str = None,
+        adls_file_name: str = None,
         adls_dir_path: str = None,
         overwrite_adls: bool = True,
         if_empty: str = "warn",
@@ -85,8 +86,8 @@ class SupermetricsToADLS(Flow):
             fields (List[str]): A query parameter passed to the SupermetricsToCSV task
             ds_segments (List[str], optional): A query parameter passed to the SupermetricsToCSV task. Defaults to None.
             date_range_type (str, optional): A query parameter passed to the SupermetricsToCSV task. Defaults to None.
-            start_date (str, optional): A query paramter to pass start date to the date range filter. Defaults to None.
-            end_date (str, optional): A query paramter to pass end date to the date range filter. Defaults to None.
+            start_date (str, optional): A query parameter to pass start date to the date range filter. Defaults to None.
+            end_date (str, optional): A query parameter to pass end date to the date range filter. Defaults to None.
             settings (Dict[str, Any], optional): A query parameter passed to the SupermetricsToCSV task. Defaults to None.
             filter (str, optional): A query parameter passed to the SupermetricsToCSV task. Defaults to None.
             max_rows (int, optional): A query parameter passed to the SupermetricsToCSV task. Defaults to 1000000.
@@ -97,6 +98,7 @@ class SupermetricsToADLS(Flow):
             keep_validation_output (bool, optional): Whether to keep the output files generated by the Great Expectations task. Defaults to False.
             Currently, only GitHub URLs are supported. Defaults to None.
             local_file_path (str, optional): Local destination path. Defaults to None.
+            adls_file_name (str, optional): Name of file in ADLS. Defaults to None.
             output_file_extension (str, optional): Output file extension - to allow selection of .csv for data which is not easy to handle with parquet. Defaults to ".parquet"..
             adls_dir_path (str, optional): Azure Data Lake destination folder/catalog path. Defaults to None.
             sep (str, optional): The separator to use in the CSV. Defaults to "\t".
@@ -152,12 +154,20 @@ class SupermetricsToADLS(Flow):
         self.local_json_path = self.slugify(name) + ".json"
         self.now = str(pendulum.now("utc"))
         self.adls_dir_path = adls_dir_path
-        self.adls_file_path = os.path.join(
-            adls_dir_path, self.now + self.output_file_extension
-        )
-        self.adls_schema_file_dir_file = os.path.join(
-            adls_dir_path, "schema", self.now + ".json"
-        )
+
+        if adls_file_name is not None:
+            self.adls_file_path = os.path.join(adls_dir_path, adls_file_name)
+            self.adls_schema_file_dir_file = os.path.join(
+                adls_dir_path, "schema", Path(adls_file_name).stem + ".json"
+            )
+
+        else:
+            self.adls_file_path = os.path.join(
+                adls_dir_path, self.now + self.output_file_extension
+            )
+            self.adls_schema_file_dir_file = os.path.join(
+                adls_dir_path, "schema", self.now + ".json"
+            )
         self.overwrite_adls = overwrite_adls
         self.if_empty = if_empty
         self.adls_sp_credentials_secret = adls_sp_credentials_secret
@@ -180,7 +190,6 @@ class SupermetricsToADLS(Flow):
     def gen_supermetrics_task(
         self, ds_accounts: Union[str, List[str]], flow: Flow = None
     ) -> Task:
-
         t = supermetrics_to_df_task.bind(
             ds_id=self.ds_id,
             ds_accounts=ds_accounts,
