@@ -174,14 +174,32 @@ class AzureDataLake(Source):
         return df
 
     def ls(self, path: str = None) -> List[str]:
+        """Returns list of files in a path.
+
+        Args:
+                path (str, optional): Path to a folder. Defaults to None.
+        """
         path = path or self.path
         return self.fs.ls(path)
 
     def rm(self, path: str = None, recursive: bool = False):
+        """Deletes files in a path.
+
+        Args:
+                path (str, optional): Path to a folder. Defaults to None.
+                recursive (bool, optional): Whether to delete files recursively or not. Defaults to False.
+        """
         path = path or self.path
         self.fs.rm(path, recursive=recursive)
 
     def cp(self, from_path: str = None, to_path: str = None, recursive: bool = False):
+        """Copies source to a destination.
+
+        Args:
+            from_path (str, optional): Path form which to copy file. Defauls to None.
+            to_path (str, optional): Path where to copy files. Defaults to None.
+            recursive (bool, optional): Whether to copy files recursively or not. Defaults to False.
+        """
         from_path = from_path or self.path
         to_path = to_path
         self.fs.cp(from_path, to_path, recursive=recursive)
