@@ -5,6 +5,7 @@ from .azure_data_lake import (
     AzureDataLakeList,
     AzureDataLakeToDF,
     AzureDataLakeUpload,
+    AzureDataLakeRemove,
 )
 from .azure_key_vault import (
     AzureKeyVaultSecret,
@@ -29,6 +30,9 @@ from .sharepoint import SharepointToDF
 from .cloud_for_customers import C4CReportToDF, C4CToDF
 from .prefect_date_range import GetFlowNewDateRange
 from .aselite import ASELiteToDF
+from .bigquery import BigQueryToDF
+from .salesforce import SalesforceUpsert, SalesforceBulkUpsert
+from .outlook import OutlookToDF
 
 try:
     from .sap_rfc import SAPRFCToDF
@@ -36,4 +40,5 @@ except ImportError:
     pass
 
 from .duckdb import DuckDBCreateTableFromParquet, DuckDBQuery, DuckDBToDF
-from .sql_server import SQLServerCreateTable
+from .sql_server import SQLServerCreateTable, SQLServerToDF
+from .epicor import EpicorOrdersToDF
