@@ -572,3 +572,99 @@ class AzureDataLakeList(Task):
         self.logger.info(f"Successfully listed files in {full_dl_path}.")
 
         return files
+
+
+class AzureDataLakeRemove(Task):
+    """
+    Task for removing objects from Azure Data Lake.
+
+    Args:
+        path (str, optional): The path to the directory from which to delete files. Defaults to None.
+        recursive (bool): Set this to true if removing entire directories.
+        gen (int, optional): The generation of the Azure Data Lake. Defaults to 2.
+        vault_name (str, optional): The name of the vault from which to fetch the secret. Defaults to None.
+        max_retries (int, optional): Maximum number of retries before failing. Defaults to 3.
+        retry_delay (timedelta, optional): Time to wait before the next retry attempt. Defaults to timedelta(seconds=10).
+    """
+
+    def __init__(
+        self,
+        path: str = None,
+        recursive: bool = False,
+        gen: int = 2,
+        vault_name: str = None,
+        max_retries: int = 3,
+        retry_delay: timedelta = timedelta(seconds=10),
+        *args,
+        **kwargs,
+    ):
+        self.path = path
+        self.recursive = recursive
+        self.gen = gen
+        self.vault_name = vault_name
+
+        super().__init__(
+            name="adls_rm",
+            max_retries=max_retries,
+            retry_delay=retry_delay,
+            *args,
+            **kwargs,
+        )
+
+    @defaults_from_attrs(
+        "path",
+        "recursive",
+        "gen",
+        "vault_name",
+        "max_retries",
+        "retry_delay",
+    )
+    def run(
+        self,
+        path: str = None,
+        recursive: bool = None,
+        gen: int = None,
+        sp_credentials_secret: str = None,
+        vault_name: str = None,
+        max_retries: int = None,
+        retry_delay: timedelta = None,
+    ) -> List[str]:
+        """Task run method.
+
+        Args:
+            path (str): The path to the directory contents of which you want to delete. Defaults to None.
+            recursive (bool): Set this to True if removing files recursively. Defaults to False.
+            gen (int): The generation of the Azure Data Lake. Defaults to None.
+            sp_credentials_secret (str, optional): The name of the Azure Key Vault secret containing a dictionary with
+            ACCOUNT_NAME and Service Principal credentials (TENANT_ID, CLIENT_ID, CLIENT_SECRET). Defaults to None.
+            vault_name (str, optional): The name of the vault from which to obtain the secret. Defaults to None.
+        """
+
+        if not sp_credentials_secret:
+            # attempt to read a default for the service principal secret name
+            try:
+                sp_credentials_secret = PrefectSecret(
+                    "AZURE_DEFAULT_ADLS_SERVICE_PRINCIPAL_SECRET"
+                ).run()
+            except ValueError:
+                pass
+
+        if sp_credentials_secret:
+            azure_secret_task = AzureKeyVaultSecret()
+            credentials_str = azure_secret_task.run(
+                secret=sp_credentials_secret, vault_name=vault_name
+            )
+            credentials = json.loads(credentials_str)
+        else:
+            credentials = {
+                "ACCOUNT_NAME": os.environ["AZURE_ACCOUNT_NAME"],
+                "AZURE_TENANT_ID": os.environ["AZURE_TENANT_ID"],
+                "AZURE_CLIENT_ID": os.environ["AZURE_CLIENT_ID"],
+                "AZURE_CLIENT_SECRET": os.environ["AZURE_CLIENT_SECRET"],
+            }
+        lake = AzureDataLake(gen=gen, credentials=credentials)
+
+        full_path = os.path.join(credentials["ACCOUNT_NAME"], path)
+        self.logger.info(f"Deleting files from {full_path}...")
+        lake.rm(path, recursive=recursive)
+        self.logger.info(f"Successfully deleted files from {full_path}.")
