@@ -1,8 +1,7 @@
 import re
-from typing import Any, Dict
+from typing import Any, Dict, List
 
 import pandas as pd
-import pendulum
 import prefect
 import pyodbc
 import requests
@@ -11,7 +10,7 @@ from requests.adapters import HTTPAdapter
 from requests.exceptions import ConnectionError, HTTPError, ReadTimeout, Timeout
 from requests.packages.urllib3.util.retry import Retry
 from urllib3.exceptions import ProtocolError
-
+from itertools import chain
 from .exceptions import APIError
 
 
@@ -116,9 +115,7 @@ def get_flow_last_run_date(flow_name: str) -> str:
         return None
 
     last_run_date_raw_format = flow_run_data[0]["start_time"]
-    last_run_date = (
-        pendulum.parse(last_run_date_raw_format).format("YYYY-MM-DDTHH:MM:SS") + "Z"
-    )
+    last_run_date = last_run_date_raw_format.split(".")[0] + "Z"
     return last_run_date
 
 
@@ -243,7 +240,9 @@ def build_merge_query(
     return merge_query
 
 
-def gen_bulk_insert_query_from_df(df: pd.DataFrame, table_fqn: str, **kwargs) -> str:
+def gen_bulk_insert_query_from_df(
+    df: pd.DataFrame, table_fqn: str, chunksize=1000, **kwargs
+) -> str:
     """
     Converts a DataFrame to a bulk INSERT query.
 
@@ -274,6 +273,25 @@ def gen_bulk_insert_query_from_df(df: pd.DataFrame, table_fqn: str, **kwargs) ->
             "Currently, this function only handles DataFrames with at least two columns."
         )
 
+    def _gen_insert_query_from_records(records: List[tuple]) -> str:
+
+        tuples = map(str, tuple(records))
+
+        # Change Nones to NULLs
+        none_nan_pattern = r"(?<=\W)(nan|None)(?=\W)"
+        values = re.sub(none_nan_pattern, "NULL", (",\n" + " " * 7).join(tuples))
+
+        # Change the double quotes into single quotes, as explained above.
+        # Note this pattern should be improved at a later time to cover more edge cases.
+        double_quotes_pattern = r'(")(.*)(")(\)|,)'
+        values_clean = re.sub(double_quotes_pattern, r"'\2'\4", values)
+        # Hacky - replaces starting and ending double quotes.
+        values_clean = (
+            values.replace('",', "',").replace(', "', ", '").replace('("', "('")
+        )
+
+        return f"INSERT INTO {table_fqn} ({columns})\n\nVALUES {values_clean}"
+
     df = df.copy().assign(**kwargs)
     df = _cast_df_cols(df)
 
@@ -292,14 +310,38 @@ def gen_bulk_insert_query_from_df(df: pd.DataFrame, table_fqn: str, **kwargs) ->
         )
         for row in tuples_raw
     ]
-    tuples = map(str, tuple(tuples_escaped))
 
-    # Change Nones to NULLs
-    none_nan_pattern = r"(?<=\W)(nan|None)(?=\W)"
-    values = re.sub(none_nan_pattern, "NULL", (",\n" + " " * 7).join(tuples))
+    if len(tuples_escaped) > chunksize:
+        insert_query = ""
+        chunk_start = 0
+        for chunk_end in range(chunksize, len(tuples_escaped), chunksize):
+            chunk = tuples_escaped[chunk_start:chunk_end]
+            chunk_start += chunksize
+            if len(tuples_escaped) - chunk_end < chunksize:
+                chunk = tuples_escaped[chunk_end:]
+            chunk_insert_query = _gen_insert_query_from_records(chunk)
+            insert_query += chunk_insert_query + ";\n\n"
+        return insert_query
+    else:
+        return _gen_insert_query_from_records(tuples_escaped)
 
-    # Change the double quotes into single quotes, as explained above.
-    # Note this pattern should be improved at a later time to cover more edge cases.
-    double_quotes_pattern = r'(")(.*)(")(\)|,)'
-    values_clean = re.sub(double_quotes_pattern, r"'\2'\4", values)
-    return f"INSERT INTO {table_fqn} ({columns})\n\nVALUES {values_clean}"
+
+def union_dict(*dicts):
+    """
+    Function that union list of dictionaries
+
+    Args:
+        dicts (List[Dict]): list of dictionaries with credentials.
+
+    Returns:
+        Dict: A single dictionary createb by union method.
+
+    Examples:
+
+    >>> a = {"a":1}
+    >>> b = {"b":2}
+    >>> union_credentials_dict(a ,b)
+    {'a': 1, 'b': 2}
+
+    """
+    return dict(chain.from_iterable(dct.items() for dct in dicts))
